activity_flow library
This file provides all the events.
Classes
- DeepLinkParams
- PageViewObserver
- A custom RouteObserver that sends page view events to ActivityFlow.
- TouchDetector
- A custom Widget that sends touch events to ActivityFlow.
Extensions
- ActivityFlowAd on Widget
- Extension to add ad analytics listeners (impression, view, click) to any Widget.
Properties
- testPageViewObserver ↔ PageViewObserver?
-
Used for unit testing to inject a mock PageViewObserver.
This should be set in test files only.
getter/setter pair
Functions
-
consumeCurrentDeepLink(
) → DeepLinkParams? -
getCurrentDeepLink(
) → DeepLinkParams? - Returns the most recent deep link captured (exported to the user).
-
initActivityFlow(
{String? accountName, Map< String, String> ? params}) → void -
trackPageView(
String pageName) → void
Typedefs
- DeepLinkCallback = void Function(DeepLinkParams params)
- Callback function type for handling deep links